import pickle
import pandas as pd
import altair as alt
from tableausdk import *
from tableausdk.HyperExtract import *


def start_tabpy():
  """
  Start a tableau server in order to allow Tableau to call python for various functions
  https://tableau.github.io/TabPy/docs/tabpy-virtualenv.html

  Parameters:
    
  """
  # simply start the server
  tabpy
  



  
  
  
  
  
